@@ -234,7 +234,7 @@ setMethod("vb", "stanmodel",
 
             vbres <- sampler$call_sampler(c(args, dotlist))
             samples <- read_one_stan_csv(attr(vbres, "args")$sample_file)
-            diagnostic_columns <- which(grepl('__',colnames(samples)))[-1]
+            diagnostic_columns <- which(grepl('__$',colnames(samples)))[-1]
             if (length(diagnostic_columns)>0) {
               diagnostics <- samples[-1,diagnostic_columns]
               samples <- samples[,-diagnostic_columns]
@@ -625,8 +625,7 @@ setMethod("sampling", "stanmodel",
                 return(out)
               }
               if ( .Platform$OS.type == "unix" &&
-                   (!interactive() || isatty(stdout()) || 
-                    identical(Sys.getenv("RSTUDIO"), "1")) ) {
+                   (!interactive() || isatty(stdout())) ) {
                 nfits <- parallel::mclapply(1:chains, FUN = callFun,
                                             mc.preschedule = FALSE,
                                             mc.cores = min(chains, cores))
@@ -656,9 +655,11 @@ setMethod("sampling", "stanmodel",
                 }
                 else sinkfile <- ""
                 if (!is.null(dots$refresh) && dots$refresh == 0)
-                  cl <- parallel::makeCluster(min(cores, chains), useXDR = FALSE)
+                  cl <- parallel::makeCluster(min(cores, chains), useXDR = FALSE,
+                                              setup_strategy = "sequential")
                 else
-                  cl <- parallel::makeCluster(min(cores, chains), outfile = sinkfile, useXDR = FALSE)
+                  cl <- parallel::makeCluster(min(cores, chains), outfile = sinkfile, 
+                                              useXDR = FALSE, setup_strategy = "sequential")
                 on.exit(parallel::stopCluster(cl))
                 dependencies <- c("rstan", "Rcpp", "ggplot2")
                 .paths <- unique(c(.libPaths(), sapply(dependencies, FUN = function(d) {
@@ -797,14 +798,14 @@ setMethod("sampling", "stanmodel",
                   if (.Platform$OS.type == "windows") {
                     print(mat)
                     print("When a numerical problem occurs, the Hamiltonian proposal gets rejected.")
-                    print("See http://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
+                    print("See https://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
                     print(paste("If the number in the 'count' column is small, ",
                                 "there is no need to ask about this message on stan-users."))
                   }
                   else {
                     message(paste(capture.output(print(mat)), collapse = "\n"))
                     message("When a numerical problem occurs, the Hamiltonian proposal gets rejected.")
-                    message("See http://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
+                    message("See https://mc-stan.org/misc/warnings.html#exception-hamiltonian-proposal-rejected")
                     message("If the number in the 'count' column is small, ",
                             "there is no need to ask about this message on stan-users.")
                   }
